import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_applicationautoscaling
import aws_cdk.aws_cloudwatch
import aws_cdk.aws_iam
import aws_cdk.aws_kms
import aws_cdk.aws_lambda
import aws_cdk.core
import aws_cdk.custom_resources
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-dynamodb", "1.42.1", __name__[0:-6], "aws-dynamodb@1.42.1.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
